#!/usr/bin/env python

import os
from distutils.core import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='starboard',
    version='0.1.1',
    description='Utilities to help with networking',
    long_description=read("README"),
    author='Michael Williamson',
    url='http://github.com/mwilliamson/starboard.py',
    packages=['starboard'],
)

